{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, MMM d, y G",
    GyMMMd => "MMM d, y G",
    GyMd => "M/d/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-one" => "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1} W \N{U+0627}\N{U+0632} MMMM",
    "MMMMW-count-other" => "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1} W \N{U+0627}\N{U+0632} MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1} w \N{U+0627}\N{U+0632} Y",
    "yw-count-other" => "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1} w \N{U+0627}\N{U+0632} Y",
  },
  code => "ks-Arab-IN",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+0698}\N{U+0654}\N{U+0646}\N{U+062f}\N{U+0655}\N{U+0631}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0628}\N{U+06c6}\N{U+0645}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0628}\N{U+0648}\N{U+062f}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0628}\N{U+0631}\N{U+0620}\N{U+0633}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+062c}\N{U+064f}\N{U+0645}\N{U+06c1}",
    "\N{U+0628}\N{U+0679}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0622}\N{U+062a}\N{U+06be}\N{U+0648}\N{U+0627}\N{U+0631}",
  ],
  day_format_narrow => [
    "\N{U+0698}",
    "\N{U+0628}",
    "\N{U+0628}",
    "\N{U+0628}",
    "\N{U+062c}",
    "\N{U+0628}",
    "\N{U+0627}",
  ],
  day_format_wide => [
    "\N{U+0698}\N{U+0654}\N{U+0646}\N{U+062f}\N{U+0631}\N{U+0655}\N{U+0631}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0628}\N{U+06c6}\N{U+0645}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0628}\N{U+0648}\N{U+062f}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0628}\N{U+0631}\N{U+0620}\N{U+0633}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+062c}\N{U+064f}\N{U+0645}\N{U+06c1}",
    "\N{U+0628}\N{U+0679}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0627}\N{U+064e}\N{U+062a}\N{U+06be}\N{U+0648}\N{U+0627}\N{U+0631}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0698}\N{U+0654}\N{U+0646}\N{U+062f}\N{U+0655}\N{U+0631}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0628}\N{U+06c6}\N{U+0645}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0628}\N{U+0648}\N{U+062f}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0628}\N{U+0631}\N{U+0620}\N{U+0633}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+062c}\N{U+064f}\N{U+0645}\N{U+06c1}",
    "\N{U+0628}\N{U+0679}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0622}\N{U+062a}\N{U+06be}\N{U+0648}\N{U+0627}\N{U+0631}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0698}",
    "\N{U+0628}",
    "\N{U+0628}",
    "\N{U+0628}",
    "\N{U+062c}",
    "\N{U+0628}",
    "\N{U+0627}",
  ],
  day_stand_alone_wide => [
    "\N{U+0698}\N{U+0654}\N{U+0646}\N{U+062f}\N{U+0631}\N{U+0655}\N{U+0631}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0628}\N{U+06c6}\N{U+0645}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0628}\N{U+0648}\N{U+062f}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0628}\N{U+0631}\N{U+0620}\N{U+0633}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+062c}\N{U+064f}\N{U+0645}\N{U+06c1}",
    "\N{U+0628}\N{U+0679}\N{U+0648}\N{U+0627}\N{U+0631}",
    "\N{U+0627}\N{U+064e}\N{U+062a}\N{U+06be}\N{U+0648}\N{U+0627}\N{U+0631}",
  ],
  era_abbreviated => [
    "\N{U+0628}\N{U+06cc} \N{U+0633}\N{U+06cc}",
    "\N{U+0627}\N{U+06d2} \N{U+0688}\N{U+06cc}",
  ],
  era_narrow => [
    "\N{U+0628}\N{U+06cc} \N{U+0633}\N{U+06cc}",
    "\N{U+0627}\N{U+06d2} \N{U+0688}\N{U+06cc}",
  ],
  era_wide => [
    "\N{U+0642}\N{U+0628}\N{U+0655}\N{U+0644} \N{U+0645}\N{U+0633}\N{U+06cc}\N{U+0656}\N{U+062d}",
    "\N{U+0627}\N{U+06cc}\N{U+0646}\N{U+0648} \N{U+0688}\N{U+0648}\N{U+0645}\N{U+0646}\N{U+06cc}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kashmiri",
  month_format_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0624}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0624}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0655}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0657}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0657}\N{U+0644}\N{U+0627}\N{U+06cc}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0657}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_format_narrow => [
    "\N{U+062c}",
    "\N{U+0641}",
    "\N{U+0645}",
    "\N{U+0627}",
    "\N{U+0645}",
    "\N{U+062c}",
    "\N{U+062c}",
    "\N{U+0627}",
    "\N{U+0633}",
    "\N{U+0633}",
    "\N{U+0627}",
    "\N{U+0646}",
  ],
  month_format_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0624}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0624}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0655}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0657}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0657}\N{U+0644}\N{U+0627}\N{U+06cc}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0657}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0624}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0624}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0655}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0657}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0657}\N{U+0644}\N{U+0627}\N{U+06cc}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0657}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_narrow => [
    "\N{U+062c}",
    "\N{U+0641}",
    "\N{U+0645}",
    "\N{U+0627}",
    "\N{U+0645}",
    "\N{U+062c}",
    "\N{U+062c}",
    "\N{U+0627}",
    "\N{U+0633}",
    "\N{U+0633}",
    "\N{U+0627}",
    "\N{U+0646}",
  ],
  month_stand_alone_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0624}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0624}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0655}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0657}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0657}\N{U+0644}\N{U+0627}\N{U+06cc}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0657}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  name => "Kashmiri India Arabic",
  native_language => "\N{U+06a9}\N{U+0672}\N{U+0634}\N{U+064f}\N{U+0631}",
  native_name => "\N{U+06a9}\N{U+0672}\N{U+0634}\N{U+064f}\N{U+0631} \N{U+06c1}\N{U+0650}\N{U+0646}\N{U+062f}\N{U+0648}\N{U+0633}\N{U+062a}\N{U+0627}\N{U+0646} \N{U+0639}\N{U+0631}\N{U+0628}\N{U+06cc}",
  native_script => "\N{U+0639}\N{U+0631}\N{U+0628}\N{U+06cc}",
  native_territory => "\N{U+06c1}\N{U+0650}\N{U+0646}\N{U+062f}\N{U+0648}\N{U+0633}\N{U+062a}\N{U+0627}\N{U+0646}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+06a9}\N{U+06cc}\N{U+0648} 1",
    "\N{U+06a9}\N{U+06cc}\N{U+0648} 2",
    "\N{U+06a9}\N{U+06cc}\N{U+0648} 3",
    "\N{U+06a9}\N{U+06cc}\N{U+0648} 4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+06af}\N{U+06c4}\N{U+0691}\N{U+0646}\N{U+06cc}\N{U+064f}\N{U+06a9} \N{U+0698}\N{U+06c4}\N{U+0628}\N{U+0627}\N{U+06af}",
    "\N{U+062f}\N{U+06c6}\N{U+06cc}\N{U+0650}\N{U+0645} \N{U+0698}\N{U+06c4}\N{U+0628}\N{U+0627}\N{U+06af}",
    "\N{U+062a}\N{U+0631}\N{U+06cc}\N{U+0650}\N{U+0645} \N{U+0698}\N{U+06c4}\N{U+0628}\N{U+0627}\N{U+06af}",
    "\N{U+0698}\N{U+0648}\N{U+0657}\N{U+0631}\N{U+0650}\N{U+0645} \N{U+0698}\N{U+06c4}\N{U+0628}\N{U+0627}\N{U+06af}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+06a9}\N{U+06cc}\N{U+0648} 1",
    "\N{U+06a9}\N{U+06cc}\N{U+0648} 2",
    "\N{U+06a9}\N{U+06cc}\N{U+0648} 3",
    "\N{U+06a9}\N{U+06cc}\N{U+0648} 4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+06af}\N{U+06c4}\N{U+0691}\N{U+0646}\N{U+06cc}\N{U+064f}\N{U+06a9} \N{U+0698}\N{U+06c4}\N{U+0628}\N{U+0627}\N{U+06af}",
    "\N{U+062f}\N{U+06c6}\N{U+06cc}\N{U+0650}\N{U+0645} \N{U+0698}\N{U+06c4}\N{U+0628}\N{U+0627}\N{U+06af}",
    "\N{U+062a}\N{U+0631}\N{U+06cc}\N{U+0650}\N{U+0645} \N{U+0698}\N{U+06c4}\N{U+0628}\N{U+0627}\N{U+06af}",
    "\N{U+0698}\N{U+0648}\N{U+0657}\N{U+0631}\N{U+0650}\N{U+0645} \N{U+0698}\N{U+06c4}\N{U+0628}\N{U+0627}\N{U+06af}",
  ],
  script => "Arabic",
  territory => "India",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 42,
}
